<?php
/**
 * smallads.php
 * $Id: smallads.php 18 2012-11-11 19:36:17Z alain091@gmail.com $
 *
 * @author         alain91
 * @copyright      (C) 2008-2012 Alain Gandon
 * @email          alain091@gmail.com
 * @license        GPL version 2
 */

defined('PATH_TO_ROOT') OR define('PATH_TO_ROOT','..');

require_once(PATH_TO_ROOT.'/kernel/begin.php');
require_once(PATH_TO_ROOT.'/smallads/smallads_begin.php');
require_once(PATH_TO_ROOT.'/smallads/smallads.class.php');
require_once(PATH_TO_ROOT.'/kernel/header.php');

//Chargement du cache
$Cache->load('smallads');

require_once(PATH_TO_ROOT.'/smallads/smallads_interface.class.php');
$tmp = new SmalladsInterface();

$tmp->on_changeday();

$smallads = new Smallads();

$checkboxes = array(
	'view_mail'	=> array('mask' => 0x01, 'value' => null, 'default' => 0, 'type' => TINTEGER),
	'view_pm'	=> array('mask' => 0x02, 'value' => null, 'default' => 0, 'type' => TINTEGER),
	);

$id_delete		= retrieve(GET, 'delete', 0, TINTEGER);
$id_delete_pict	= retrieve(GET, 'delete_picture', 0, TINTEGER);
$id_edit 		= retrieve(GET, 'edit', 0, TINTEGER);
$id_add 		= retrieve(GET, 'add', 0, TINTEGER);
$id_view 		= retrieve(GET, 'id', 0, TINTEGER);

function render_view($smallads, $row)
{
	global $Template, $User, $LANG, $type_options, $checkboxes;

	$user 		= $User->get_id();
	$id_created = (int)$row['id_created'];
	$c_edit 	= FALSE;
	$url_edit	= '';
	$c_delete	= FALSE;
	$url_delete	= '';

	$v = $smallads->check_access(UPDATE_ACCESS, (OWN_CRUD_ACCESS|CONTRIB_ACCESS), $id_created);
	if ($v)
	{
		$url_edit 	= url('.php?edit=' . $row['id']);
		$c_edit 	= TRUE;
	}

	$v = $smallads->check_access(DELETE_ACCESS, (OWN_CRUD_ACCESS|CONTRIB_ACCESS), $id_created);
	if ($v)
	{
		$url_delete	= url('.php?delete=' . $row['id']);
		$c_delete	= TRUE;
	}

	$is_user	= ((!empty($row['id_created']))
						&& ($row['id_created'] > 0));

	$is_pm 		= ((!empty($row['id_created']))
						&& (intval($row['id_created']) != $user)
						&& ($smallads->config_get('view_pm',0))
                        && ($row['links_flag'] & $checkboxes['view_pm']['mask']));

	$is_mail 	= ((!empty($row['user_mail']))
						&& (!empty($row['user_show_mail']))
						&& (!empty($row['id_created']))
						&& (intval($row['id_created']) != $user)
						&& ($smallads->config_get('view_mail',0))
                        && ($row['links_flag'] & $checkboxes['view_mail']['mask']));

	if ($is_mail)
	{
		$mailto = $row['user_mail'];
		$mailto .= "?subject=Petite annonce #".$row['id']." : ".$row['title'];
		$mailto .= "&body=Bonjour,";
	}

	$Template->assign_block_vars('item',array(
		'ID' 		=> $row['id'],
		'VID'		=> empty($row['vid']) ? '' : $row['vid'],
		'TYPE'	 	=> $type_options[intval($row['type'])],
		'TITLE' 	=> htmlentities($row['title']),
		'CONTENTS' 	=> second_parse($row['contents']),
		'PRICE'		=> $row['price'],

		'DB_CREATED' => (!empty($row['date_created'])) ? $LANG['sa_created'].gmdate_format('date_format', $row['date_created']) : '',
		'DB_UPDATED' => (!empty($row['date_updated'])) ? $LANG['sa_updated'].gmdate_format('date_format', $row['date_updated']) : '',
		'C_DB_APPROVED'	 => !empty($row['approved']) ? TRUE : FALSE,
		'L_NOT_APPROVED' => $LANG['sa_not_approved'],

		'C_EDIT' 	=> $c_edit,
		'URL_EDIT'	=> $url_edit,
		'C_DELETE'	=> $c_delete,
		'URL_DELETE' => $url_delete,
		'L_CONFIRM_DELETE' => $LANG['sa_confirm_delete'],
		'URL_VIEW'	=> url('.php?id=' . $row['id']),

		'C_PICTURE'	 => !empty($row['picture']) ? TRUE : FALSE,
		'PICTURE'	 => PATH_TO_ROOT.'/smallads/pics/'.$row['picture'],

		'USER'		=> $is_user ? '<a href="'.PATH_TO_ROOT.'/member/member'. url('.php?id=' . $row['id_created'], '-' . $row['id_created'] . '.php') .'">'.$row['login'].'</a>' : '',
		'USER_PM' 	=> $is_pm ? '&nbsp;: <a href="'.PATH_TO_ROOT.'/member/pm' . url('.php?pm=' . $row['id_created'], '-' . $row['id_created'] . '.php') . '"><img src="'.PATH_TO_ROOT.'/templates/' . get_utheme() . '/images/' . get_ulang() . '/pm.png" alt="pm" /></a>' : '',
		'USER_MAIL' => $is_mail ? '&nbsp;<a href="mailto:' . $mailto . '"><img src="'.PATH_TO_ROOT.'/templates/' . get_utheme() . '/images/' . get_ulang() . '/email.png" alt="' . $row['user_mail']  . '" title="' . $row['user_mail']  . '" /></a>' : '',
	));
}

if( retrieve(POST, 'submit', false) ) //Enregistrement du formulaire
{
	$Session->csrf_get_protect(); //Protection complementaire csrf

	$id_post        = intval(retrieve(POST, 'id', 0, TINTEGER));

	if (empty($id_post)) // Creation
	{
		$smallads->check_autorisation(OWN_CRUD_ACCESS|CONTRIB_ACCESS);
	}
	else
	{
		$smallads->check_autorisation(OWN_CRUD_ACCESS|UPDATE_ACCESS|CONTRIB_ACCESS);
	}

	$sa_title 		= retrieve(POST, 'smallads_title', '', TSTRING_UNCHANGE);
	$sa_contents 	= retrieve(POST, 'smallads_contents', '', TSTRING_UNCHANGE);
	$sa_contents	= strparse($sa_contents, $forgiven_tags, FALSE); // TSTRING_PARSE ne permet pas les parametres
	$sa_price 		= retrieve(POST, 'smallads_price', 0.0, TFLOAT);
	$sa_type   		= retrieve(POST, 'smallads_type', 0, TINTEGER);
	$sa_max_weeks	= retrieve(POST, 'smallads_max_weeks', 0, TINTEGER);
	$sa_max_weeks	= empty($sa_max_weeks) ? 'NULL' : abs($sa_max_weeks);

	$flag = 0;
    $config_flag = 0;
	foreach($checkboxes as $k => $v)
	{
		$link = retrieve(POST, $k, $v['default'], $v['type']);
        $config_link = $smallads->config_get($k, 0) * $v['mask'];
		$flag |= $link; // logical or between each checkbox value
        $config_flag |= $config_link; // logical or between each checkbox value
	}
    $flag &= $config_flag; // verifie par rapport aux parametres admin

	if ( empty($sa_contents) || empty($sa_title) )
	{
		$Errorh->handler('e_incomplete', E_USER_REDIRECT);
		exit;
	}

	//Mod anti-flood
	$check_time = 0;
	$user_id = $User->get_id();
	if ($user_id > 0 && $CONFIG['anti_flood'] == 1)
	{
		$check_time = $Sql->query("SELECT MAX(date_created) as date_created
									FROM ".PREFIX."smallads
									WHERE id_created = '" . $user_id . "'",
									__LINE__, __FILE__);
	}
	if (!empty($check_time))
	{
		if( $check_time >= (time() - $CONFIG['delay_flood']) ) //On calcul la fin du delai.
		{
			$Errorh->handler('e_flood', E_USER_REDIRECT);
			exit;
		}
	}

	if (empty($id_post)) // Creation
	{
		if ($user_id  <= 0)
		{
			$Errorh->handler('e_auth', E_USER_REDIRECT);
			Exit;
		}

		$db_approved = $smallads->access_ok(OWN_CRUD_ACCESS) ? 1 : 0;
		$date = time();

		$sql = "INSERT INTO ".PREFIX."smallads
				SET
					title     = '" . $Sql->escape($sa_title) . "',
					contents  = '" . $Sql->escape($sa_contents) . "',
					type      = '" . $sa_type . "',
					price     = " . $sa_price . ",
					id_created    = " . $user_id . ",
					date_created  = " . $date . ",
					links_flag    = " . $flag . ",
					max_weeks = " . $sa_max_weeks;

		if ($db_approved) {
			$sql .= ",
					approved      = " . $db_approved.",
					date_approved = " . $date;
		} else {
			$sql .= ",
					approved      = 0,
					date_approved = 0";
		}

		$Sql->query_inject($sql, __LINE__, __FILE__);

		$last_id = intval($Sql->insert_id(""));
		$smallads->upload_picture($last_id);

		// Feeds Regeneration
		import('content/syndication/feed');
		Feed::clear_cache('smallads');
		// Cache Regeneration
		$Cache->generate_module_file('smallads');

		if (!$smallads->access_ok(OWN_CRUD_ACCESS) && $smallads->access_ok(CONTRIB_ACCESS))
		{
			$contribution_counterpart = retrieve(POST, 'contribution_counterpart', '', TSTRING_UNCHANGE);
			$smallads->contribution_add($last_id, $contribution_counterpart);
			redirect(HOST . DIR . '/smallads/contribution.php');
			exit;
		}

	} else { // Modification

		$smallads_properties = $Sql->query_array(PREFIX . "smallads", 'approved', 'id_created', "WHERE id = '" . $id_post . "'", __LINE__, __FILE__);

		if ( $smallads_properties === FALSE) {
			$Errorh->handler('e_unexist_page', E_USER_REDIRECT);
			exit;
		}

		$update_ok = $smallads->check_access(UPDATE_ACCESS, (OWN_CRUD_ACCESS|CONTRIB_ACCESS), intval($smallads_properties['id_created']));
		if (!$update_ok)
		{
			$Errorh->handler('e_auth', E_USER_REDIRECT);
			Exit;
		}

		if ($smallads->access_ok(UPDATE_ACCESS|OWN_CRUD_ACCESS))
		{
			if ( !empty($smallads_properties['approved']) )
			{
				$Sql->query_inject(
					"UPDATE ".PREFIX."smallads
						SET
							title     = '" . $Sql->escape($sa_title) . "',
							contents  = '" . $Sql->escape($sa_contents) . "',
							type      = " . $sa_type . ",
							price     = " . $sa_price . ",
							id_updated   = " . $user_id . ",
							date_updated = " . time() . ",
							links_flag   = " . $flag . ",
							max_weeks = " . $sa_max_weeks . "
						WHERE id ='".$id_post."'
						LIMIT 1",
						__LINE__, __FILE__);

				$smallads->upload_picture($id_post);
			}

			$sa_approved  	= retrieve(POST, 'smallads_approved', '', TNONE);
			$db_approved	= !empty($sa_approved) ? 1 : 0;

			if ($smallads->access_ok(UPDATE_ACCESS) && $db_approved && empty($smallads_properties['approved']))
			{
				$date = time();

				$doublon = $Sql->query_array(PREFIX . "smallads", 'vid', 'id_created', 'date_created', "WHERE id = " . $id_post, __LINE__, __FILE__);
				if ( !empty($doublon['vid']) )
				{
					$Sql->query_inject(
						"UPDATE ".PREFIX."smallads
							SET
								title     = '" . $Sql->escape($sa_title) . "',
								contents  = '" . $Sql->escape($sa_contents) . "',
								type      = " . $sa_type . ",
								price     = " . $sa_price . ",
								id_created    = ".$doublon['id_created'].",
								date_created  = ".$doublon['date_created'].",
								id_updated    = " . $user_id . ",
								date_updated  = " . $date . ",
								links_flag    = " . $flag . ",
								approved  	  = " . $db_approved . ",
								date_approved = " . $date . "
							WHERE id =".$doublon['vid']."
							LIMIT 1",
							__LINE__, __FILE__);

					$Sql->query_inject(
						"UPDATE ".PREFIX."smallads
							SET
								title     	= '',
								contents  	= '',
								type      	= 0,
								price     	= 0.0,
								id_created    	= 0,
								date_created 	= 0,
								id_updated   	= 0,
								date_updated 	= 0,
								links_flag   	= 0,
								approved  		= 2,
								date_approved 	= 0
							WHERE id =". $id_post."
							LIMIT 1",
							__LINE__, __FILE__);
				}
				else
				{
					$Sql->query_inject(
						"UPDATE ".PREFIX."smallads
							SET
								title     = '" . $Sql->escape($sa_title) . "',
								contents  = '" . $Sql->escape($sa_contents) . "',
								type      = " . $sa_type . ",
								price     = " . $sa_price . ",
								id_updated    = " . $user_id . ",
								date_updated  = " . $date . ",
								links_flag    = " . $flag . ",
								approved  	  = " . $db_approved . ",
								date_approved = " . $date . "
							WHERE id =".$id_post."
							LIMIT 1",
							__LINE__, __FILE__);
				}

				$smallads->contribution_set_processed($id_post);
			}

			// Feeds Regeneration
			import('content/syndication/feed');
			Feed::clear_cache('smallads');
			// Cache Regeneration
			$Cache->generate_module_file('smallads');
		}
		elseif($smallads->access_ok(CONTRIB_ACCESS))
		{
			$in_progress = $smallads->contribution_is_in_progress($id_post);
			if ($in_progress)
			{
				$Errorh->handler('sa_contrib_in_progress', E_USER_REDIRECT);
				exit;
			}

			if ( empty($smallads_properties['approved']) )
			{
				$Sql->query_inject(
					"UPDATE ".PREFIX."smallads
						SET
							title     = '" . $Sql->escape($sa_title) . "',
							contents  = '" . $Sql->escape($sa_contents) . "',
							type      = " . $sa_type . ",
							price     = " . $sa_price . ",
							id_updated   = " . $user_id . ",
							date_updated = " . time() . ",
							links_flag   = " . $flag . "
						WHERE id ='".$id_post."'
						LIMIT 1",
						__LINE__, __FILE__);

				$id_picture = $id_post;
				$id_contrib = $id_post;
			}
			else
			{
				$row = $Sql->query_array(PREFIX . "smallads", 'id',"WHERE vid = " . $id_post, __LINE__, __FILE__);
				$row2 = $Sql->query_array(PREFIX . "smallads", '*',"WHERE id = " . $id_post, __LINE__, __FILE__);
				//Le doublon existe-t-il ?
				if ( $row === FALSE ) {
					// NON on le cre
					$sql = "INSERT INTO ".PREFIX."smallads
							SET
								title     = '" . $Sql->escape($sa_title) . "',
								contents  = '" . $Sql->escape($sa_contents) . "',
								type      = '" . $sa_type . "',
								price     = " . $sa_price . ",
								id_created    = " . $user_id . ",
								date_created  = " . $row2['date_created'] . ",
								approved  	  = 0,
								date_approved = 0,
								vid           = " . $row2['id'] .",
								links_flag    = " . $flag;

					$Sql->query_inject($sql, __LINE__, __FILE__);

					$id_contrib = intval($Sql->insert_id(''));
					$id_picture = $id_contrib;
				}
				else
				{
					// OUI Mise a jour du doublon
					$Sql->query_inject(
						"UPDATE ".PREFIX."smallads
							SET
								title     = '" . $Sql->escape($sa_title) . "',
								contents  = '" . $Sql->escape($sa_contents) . "',
								type      = " . $sa_type . ",
								price     = " . $sa_price . ",
								id_created    = " . $user_id . ",
								date_created  = " . $row2['date_created'] . ",
								id_updated    = " . $user_id . ",
								date_updated  = " . time() . ",
								approved      = 0,
								date_approved = 0,
								links_flag    = " . $flag . "
							WHERE id = ".$row['id']."
							LIMIT 1",
							__LINE__, __FILE__);

					$id_contrib = $row['id'];
					$id_picture = $id_contrib;
				}
			}

			$smallads->upload_picture($id_picture);

			// update d'une contribution non traite
			$contribution_counterpart = retrieve(POST, 'contribution_counterpart', '', TSTRING_UNCHANGE);
			if (!$smallads->contribution_update($id_contrib, 'Modif id # '.$row2['id'].' - '.$contribution_counterpart))
			{
				// il faut creer une nouvelle demande de contribution
				$smallads->contribution_add($id_contrib, 'Modif id # '.$row2['id'].' - '.$contribution_counterpart);
			}

			// Feeds Regeneration
			import('content/syndication/feed');
			Feed::clear_cache('smallads');
			// Cache Regeneration
			$Cache->generate_module_file('smallads');
			redirect(HOST . DIR . '/smallads/contribution.php');
			exit;
		}
	}

	if (empty($id_post))
	{
		redirect(HOST . SCRIPT . SID2);
	}
	else
	{
		$v = $smallads->config_get('return_to_list',0);
		if ( $v == 0 )
		{
			redirect(HOST . SCRIPT . SID2 . '?edit=' . $id_post . '&s=1');
		}
		else
		{
			redirect(HOST . SCRIPT . SID2);
		}
	}
	exit;
}
elseif ($id_delete)
{
	$Session->csrf_get_protect(); //Protection csrf

	$smallads->check_autorisation(DELETE_ACCESS|OWN_CRUD_ACCESS|CONTRIB_ACCESS);

	$row = $Sql->query_array(PREFIX . "smallads", 'picture', 'id_created', 'approved', 'vid', "WHERE id = " . $id_delete, __LINE__, __FILE__);
	if ( $row === FALSE) {
		$Errorh->handler('e_unexist_page', E_USER_REDIRECT);
		exit;
	}

	$delete_ok = $smallads->check_access(DELETE_ACCESS, (OWN_CRUD_ACCESS|CONTRIB_ACCESS), intval($row['id_created']));
	if (!$delete_ok)
	{
		$Errorh->handler('e_auth', E_USER_REDIRECT);
		Exit;
	}

	$filename = $row['picture'];

	if ( $id_delete > 0 )
	{
		if ($smallads->access_ok(DELETE_ACCESS|OWN_CRUD_ACCESS))
		{
			$Sql->query_inject("DELETE FROM ".PREFIX."smallads WHERE (id = " . $id_delete .") LIMIT 1", __LINE__, __FILE__);
			if ( !empty($filename) )
			{
				@unlink (PATH_TO_ROOT.'/smallads/pics/'.$filename);
			}
		}
		elseif($smallads->access_ok(CONTRIB_ACCESS))
		{
			// PA originale
			if ( empty($row['vid']) )
			{
				$doublon = 	$row = $Sql->query_array(PREFIX . "smallads", 'approved', 'id', 'picture', "WHERE vid = " . $id_delete, __LINE__, __FILE__);

				if ( $doublon === FALSE ) // Pas de doublon
				{
					$in_progress = $smallads->contribution_is_in_progress($id_delete);
					if ($in_progress)
					{
						$Errorh->handler('sa_contrib_in_progress', E_USER_REDIRECT);
						exit;
					}
					$smallads->contribution_delete($id_delete);

					$Sql->query_inject("DELETE FROM ".PREFIX."smallads WHERE (id = " . $id_delete .") LIMIT 1", __LINE__, __FILE__);
					if ( !empty($filename) )
					{
						@unlink (PATH_TO_ROOT.'/smallads/pics/'.$filename);
					}
				}
				else
				{
					$id_doublon = $doublon['id'];
					$in_progress = $smallads->contribution_is_in_progress($id_doublon);
					if ($in_progress)
					{
						$Errorh->handler('sa_contrib_in_progress', E_USER_REDIRECT);
						exit;
					}
					$smallads->contribution_delete($id_doublon);

					$Sql->query_inject("DELETE FROM ".PREFIX."smallads WHERE (id = " . $id_doublon .") LIMIT 1", __LINE__, __FILE__);
					if ( !empty($filename) )
					{
						@unlink (PATH_TO_ROOT.'/smallads/pics/'.$doublon['picture']);
					}
				}
			}
			else // C'est le doublon
			{
				if ( empty($row['approved']) )
				{
					$in_progress = $smallads->contribution_is_in_progress($id_delete);
					if ($in_progress)
					{
						$Errorh->handler('sa_contrib_in_progress', E_USER_REDIRECT);
						exit;
					}

					$Sql->query_inject(
						"UPDATE ".PREFIX."smallads
							SET
								title     	= '',
								contents  	= '',
								type      	= 0,
								price     	= 0.0,
								id_created    	= 0,
								date_created 	= 0,
								id_updated   	= 0,
								date_updated 	= 0,
								links_flag   	= 0,
								approved  		= 2,
								date_approved 	= 0
							WHERE id =". $id_delete."
							LIMIT 1",
							__LINE__, __FILE__);
					$smallads->contribution_delete($id_delete);
				}
			}
		}

		// Feeds Regeneration
		import('content/syndication/feed');
		Feed::clear_cache('smallads');
		// Cache Regeneration
		$Cache->generate_module_file('smallads');
	}
	redirect(HOST . SCRIPT . SID2);
	exit;
}
elseif ($id_delete_pict)
{
	$Session->csrf_get_protect(); //Protection csrf

	$smallads->check_autorisation(UPDATE_ACCESS|OWN_CRUD_ACCESS);

	$row = $Sql->query_array(PREFIX . "smallads", 'picture', 'id_created', "WHERE id = " . $id_delete_pict, __LINE__, __FILE__);
	if ( $row === FALSE) {
		$Errorh->handler('e_unexist_page', E_USER_REDIRECT);
		exit;
	}

	$delete_ok = $smallads->check_access(UPDATE_ACCESS, (OWN_CRUD_ACCESS), intval($row['id_created']));
	if (!delete_ok)
	{
		$Errorh->handler('e_auth', E_USER_REDIRECT);
		Exit;
	}

	$filename = $row['picture'];

	if ( $id_delete_pict > 0 )
	{
		$Sql->query_inject("UPDATE ".PREFIX."smallads SET picture = NULL WHERE id = " . $id_delete_pict . " LIMIT 1", __LINE__, __FILE__);
		if ( !empty($filename) )
		{
			@unlink (PATH_TO_ROOT.'/smallads/pics/'.$filename);
		}
		$Cache->generate_module_file('smallads'); //Rgnration du cache
	}

	redirect(HOST . SCRIPT . SID2 . '?edit=' . $id_delete_pict . '&s=1');
	exit;
}
elseif ($id_view)
{
	$result = $Sql->query_while("SELECT q.*, m.*
		FROM ".PREFIX."smallads q
		LEFT JOIN ".PREFIX."member m ON m.user_id = q.id_created
		WHERE  id=" . $id_view ."
		LIMIT 1",
		__LINE__, __FILE__);

	$row = $Sql->fetch_assoc($result);
	if ( $row === FALSE) {
		$Errorh->handler('e_unexist_page', E_USER_REDIRECT);
		exit;
	}
	else
	{
		$smallads->check_autorisation(LIST_ACCESS);
	}

	$Template->set_filenames(array(
		'smallads' => 'smallads/smallads.tpl'
	));

	$c_add		= FALSE;
	$url_add 	= '';

	$v = ($smallads->access_ok(OWN_CRUD_ACCESS|CONTRIB_ACCESS));
	if ($v)
	{
		$url_add 	= url('.php?add=1');
		$c_add	 	= TRUE;
		$url_edit 	= url('.php?edit='.$id_view);
		$c_edit	 	= TRUE;
	}
	unset($v);

	$v = ($smallads->access_ok(DELETE_ACCESS));
	if ($v)
	{
		$url_delete	= url('.php?delete='.$id_view);
		$c_delete 	= TRUE;
	}
	unset($v);

	$Template->assign_vars(array(
		'C_VIEW'         => TRUE,
		'C_DESCRIPTION'	 => FALSE,
		'DESCRIPTION'	 => 'Champ description',
		'THEME'			 => get_utheme(),
		'LANG'			 => get_ulang(),
		'C_NB_SMALLADS'	 => TRUE,
		'L_NO_SMALLADS'	 => $LANG['sa_no_smallads'],
		'L_LIST_NOT_APPROVED'	=> $LANG['sa_list_not_approved'],
		'L_PRICE'		 => $LANG['sa_db_price'],
		'L_PRICE_UNIT'	 => $LANG['sa_price_unit'],
		'C_ADD'			 => $c_add,
		'URL_ADD'		 => $url_add,
		'TARGET_ON_CHANGE_ORDER' => 'smallads.php?',
	));

	render_view($smallads, $row);

	$Template->pparse('smallads');
}
elseif ($id_edit || $id_add)
{
	//$Session->csrf_get_protect(); //Protection csrf

	if ($id_edit != 0)
	{
		$smallads->check_autorisation(UPDATE_ACCESS|OWN_CRUD_ACCESS|CONTRIB_ACCESS);
	}
	elseif($id_add != 0)
	{
		$smallads->check_autorisation(OWN_CRUD_ACCESS|CONTRIB_ACCESS);
	}
	else
	{
		$Errorh->handler('e_unexist_page', E_USER_REDIRECT);
		exit;
	}

	$Template->set_filenames(array(
		'smallads' => 'smallads/smallads.tpl'
	));

	//Gestion erreur.
	$get_error = retrieve(GET, 's', 0, TINTEGER);
	if ($get_error == 1)
	{
		$Errorh->handler($LANG['sa_edit_success'], E_USER_SUCCESS);
	}

	$id = 0;
	$c_contribution = FALSE;
	$c_can_approve 	= FALSE;

	if ($id_edit != 0)
	{
		$row = $Sql->query_array(PREFIX . "smallads", '*', "WHERE id = " . $id_edit, __LINE__, __FILE__);
		if ( $row === FALSE)
		{
			$Errorh->handler('e_unexist_page', E_USER_REDIRECT);
			exit;
		}

		$update_ok = $smallads->check_access(UPDATE_ACCESS, (OWN_CRUD_ACCESS|CONTRIB_ACCESS), intval($row['id_created']));
		if (!$update_ok)
		{
			$Errorh->handler('e_auth', E_USER_REDIRECT);
			Exit;
		}

		$legend 		= $LANG['sa_update_legend'];
		$id 			= $id_edit;
		$c_contribution = (!$smallads->access_ok(OWN_CRUD_ACCESS|UPDATE_ACCESS) && $smallads->access_ok(CONTRIB_ACCESS));
		$c_can_approve	= ( $smallads->access_ok(UPDATE_ACCESS) && empty($row['approved']));
	}
	elseif($id_add != 0)
	{
		$result = $Sql->query_inject("SHOW COLUMNS FROM ".PREFIX."smallads", __LINE__, __FILE__);
		$row = array();
		while ($field = $Sql->fetch_assoc($result)) {
			$row[$field['Field']] = '';
		}
		$row['approved'] = 1; // on simule "approuv" sur add
		$legend 		= $LANG['sa_add_legend'];
		$c_contribution = !$smallads->access_ok(OWN_CRUD_ACCESS) AND $smallads->access_ok(CONTRIB_ACCESS);
	}

	$maxlen = $smallads->config_get('maxlen_contents', MAXLEN_CONTENTS);

	$usage_terms = $smallads->config_get('usage_terms',0);
	$cgu_contents = '';
	if (!empty($usage_terms))
		$cgu_contents = $smallads->get_cgu();

	$max_weeks_default = '';
	if (!empty($CONFIG_SMALLADS['max_weeks']))
	{
		$max_weeks_default = sprintf($LANG['sa_max_weeks_default'], $CONFIG_SMALLADS['max_weeks']);
	}

	$Template->assign_vars(array(
		'C_FORM'			=> TRUE,
		'C_CONTRIBUTION'	=> $c_contribution,
		'C_CAN_APPROVE'		=> $c_can_approve,
		'C_PICTURE'			=> empty($row['picture']) ? FALSE : TRUE,

		'THEME'				=> get_utheme(),
		'LANG'				=> get_ulang(),
		'KERNEL_EDITOR'		=> display_editor('smallads_contents', $forgiven_tags),

		'L_ALERT_TEXT'		=> $LANG['require_text'],
		'L_ALERT_FLOAT'		=> $LANG['sa_require_float'],
		'L_ALERT_UPLOAD'	=> $LANG['sa_require_upload'],
		'L_REQUIRE'			=> $LANG['require'],
		'L_LEGEND'			=> $legend,
		'L_CONFIRM_DELETE_PICTURE' 	=> $LANG['sa_confirm_delete_picture'],
		'C_USAGE_TERMS'		=> $smallads->config_get('usage_terms',0),
		'L_USAGE_LEGEND'	=> $LANG['sa_usage_legend'],
		'L_AGREE_TERMS'		=> $LANG['sa_agree_terms'],
		'CGU_CONTENTS'		=> second_parse($cgu_contents),
		'L_CGU_NOT_AGREED'	=> $LANG['sa_e_cgu_not_agreed'],
		'L_MAX_WEEKS_DEFAULT' => $max_weeks_default,

		'MAX_FILESIZE_KO'	=> MAX_FILESIZE_KO,

		'ID'				=> $id,
		'DB_TYPE'	 		=> $type_options[intval($row['type'])],
		'DB_TITLE'			=> $row['title'],
		'DB_CONTENTS'		=> unparse($row['contents']),
		'DB_PRICE'			=> $row['price'],
		'DB_APPROVED'		=> $row['approved'] != 0 ? 'checked' : '',
		'DB_CREATED'		=> (!empty($row['date_created'])) ? $LANG['sa_created'].gmdate_format('date_format', $row['date_created']) : '',
		'DB_UPDATED'		=> (!empty($row['date_updated'])) ? $LANG['sa_updated'].gmdate_format('date_format', $row['date_updated']) : '',
		'DB_PICTURE'		=> PATH_TO_ROOT.'/smallads/pics/'.$row['picture'].'?'.uniqid(rand()),
		'DB_MAX_WEEKS'		=> $row['max_weeks'],

		'DB_MAXLEN'			=> $maxlen,
		'DB_CONTENTS_REMAIN'	=>  $maxlen - strlen($row['contents']),

		'L_DB_TYPE'			=> $LANG['sa_db_type'],
		'L_DB_TITLE'		=> $LANG['sa_db_title'],
		'L_DB_CONTENTS'		=> $LANG['sa_db_contents'],
		'L_DB_PRICE'		=> $LANG['sa_db_price'],
		'L_DB_APPROVED'		=> $LANG['sa_db_approved'],
		'L_DB_PICTURE'		=> $LANG['sa_db_picture'],
		'L_DB_MAX_WEEKS'	=> $LANG['sa_max_weeks'],

		'L_PRICE_UNIT'		=> $LANG['sa_price_unit'],

		'L_SUBMIT'			=> $LANG['submit'],
		'L_PREVIEW'			=> $LANG['preview'],
		'L_RESET'			=> $LANG['reset']
	));


	$flag = empty($row['links_flag']) ? 0 : intval($row['links_flag']);

	foreach ($checkboxes as $k => $v)
	{
		if ($id_edit != 0)
		{
			$t = $v['mask'] & $flag;
		}
		elseif($id_add != 0)
		{
			$t = 1; // Force to not empty
		}
        if ($smallads->config_get($k, 0))
        {
            $Template->assign_block_vars('checkbox', array(
                'L_LABEL' => $LANG['sa_'.$k],
                'NAME'    => $k,
                'CHECKED' => (!empty($t)) ? 'checked="checked"' : '',
                'VALUE'   => $v['mask']
            ));
        }
	}

	$c_contrib = !$smallads->access_ok(OWN_CRUD_ACCESS) && $smallads->access_ok(CONTRIB_ACCESS);

	$Template->assign_vars(array(
		'C_CONTRIBUTION' 					 => $c_contrib,
		'L_CONTRIBUTION'					 => $LANG['sa_contribution_legend'],
		'L_CONTRIBUTION_NOTICE' 			 => $LANG['sa_contribution_notice'],
		'L_CONTRIBUTION_COUNTERPART' 		 => $LANG['sa_contribution_counterpart'],
		'L_CONTRIBUTION_COUNTERPART_EXPLAIN' => $LANG['sa_contribution_counterpart_explain'],
		'CONTRIBUTION_COUNTERPART_EDITOR' 	 => display_editor('counterpart')
	));

	$types = $type_options;
	unset($types[0]);
	foreach ($types as $k => $v) {
		$Template->assign_block_vars('type_options_edit',array(
			'NAME' 		=> $v,
			'SELECTED'	=> $smallads->selected($k, intval($row['type'])),
			'VALUE' 	=> $k));
	}

	$Template->pparse('smallads');
}
else //Affichage en liste par dfaut
{
	$smallads->check_autorisation(LIST_ACCESS);

	$user = $User->get_id();

	$Template->set_filenames(array(
		'smallads' => 'smallads/smallads.tpl'
	));

	$sort = retrieve(GET, 'sort', '', TSTRING_UNCHANGE);
	if (empty($sort) || !array_key_exists($sort, $sort_options))
	{
		$sort = 'date_created';
	}

	$mode = retrieve(GET, 'mode', '', TSTRING_UNCHANGE);
	if (empty($mode) || !array_key_exists($mode, $mode_options))
	{
		$mode = 'desc';
	}

	$order = $sort . ' ' . $mode;

	$type = retrieve(GET, 'type', 0, TINTEGER);

	$view_not_approved = retrieve(GET, 'ViewNotApproved', 0, TINTEGER);
	$filter = array('(approved = 1)');
	if ($view_not_approved) {
		if ($smallads->access_ok(DELETE_ACCESS))
		{
			$filter = array('(approved = 0)');
		}
		elseif($smallads->access_ok(CONTRIB_ACCESS))
		{
			$filter = array('(approved = 0) AND (id_created = '.$user.')');
		}
	}

	if (!empty($type))
	{
		$filter[] = '(type = '.intval($type).')';
	}

	$nbr_smallads = $Sql->query("SELECT COUNT(1) AS total
        FROM ".PREFIX . "smallads
        WHERE  ".implode(' AND ', $filter),
        __LINE__, __FILE__);
	$nbr_smallads = intval($nbr_smallads);

	import('util/pagination');
	$Pagination = new Pagination();

	$qs = '';
	if (!empty($_SERVER['QUERY_STRING'])) {
		$t = explode('&', $_SERVER['QUERY_STRING']);
		foreach ($t as $k => $v) {
			if (strstr($v,'p=')) unset($t[$k]);
		}
		if (count($t)>0) {
			$qs = implode('&', $t);
			$qs = '&'.$qs;
		}
	}

	$c_add	 	= FALSE;
	$url_add	= '';
	$v = ($smallads->access_ok(OWN_CRUD_ACCESS|CONTRIB_ACCESS));
	if ($v)
	{
		$url_add 	= url('.php?add=1');
		$c_add	 	= TRUE;
	}

	$items_per_page = $smallads->config_get('items_per_page', ITEMS_PER_PAGE);
	$max_links      = $smallads->config_get('max_links', MAX_LINKS);


	$Template->assign_vars(array(
		'C_LIST'         => $smallads->access_ok(LIST_ACCESS),
		'C_DESCRIPTION'	 => FALSE,
		'DESCRIPTION'	 => 'Champ description',
		'THEME'			 => get_utheme(),
		'LANG'			 => get_ulang(),
		'C_NB_SMALLADS'	 => ($nbr_smallads > 0) ? 1 : 0,
		'L_NO_SMALLADS'	 => $LANG['sa_no_smallads'],
		'L_LIST_NOT_APPROVED' => $LANG['sa_list_not_approved'],
		'L_PRICE'		 => $LANG['sa_db_price'],
		'L_PRICE_UNIT'	 => $LANG['sa_price_unit'],
		'C_ADD'			 => $c_add,
		'URL_ADD'		 => $url_add,
		'TARGET_ON_CHANGE_ORDER' => 'smallads.php?',
		'PAGINATION'     => $Pagination->display('smallads' . url('.php?p=%d'.$qs), $nbr_smallads, 'p', $items_per_page, $max_links),
	));

	$result = $Sql->query_while("SELECT q.*, m.*
		FROM ".PREFIX."smallads q
		LEFT JOIN ".PREFIX."member m ON m.user_id = q.id_created
		WHERE  ".implode(' AND ', $filter)."
		ORDER BY ".$order." "
		. $Sql->limit($Pagination->get_first_msg($items_per_page, 'p'), $items_per_page),
		__LINE__, __FILE__);

	while ($row = $Sql->fetch_assoc($result))
	{
		render_view($smallads, $row);
	}
	$Sql->query_close($result);

	foreach ($type_options as $k => $v)
	{
		$checked  = ($k == $type) ? 'checked' : '';
		$Template->assign_block_vars('type_options',array(
			'NAME' 		=> $v,
			'CHECKED'	=> $checked,
			'VALUE' 	=> $k));

		if ($k == 0) continue; // don't display 'All' option if edit form
		$Template->assign_block_vars('type_options_edit',array(
			'NAME' 		=> $v,
			'SELECTED'	=> $smallads->selected($k, intval($row['type'])),
			'VALUE' 	=> $k));
	}

	foreach ($sort_options as $k => $v)
	{
		$Template->assign_block_vars('sort_options',array(
			'NAME' 		=> $v,
			'SELECTED'	=> $smallads->selected($k, $sort),
			'VALUE' 	=> $k));
	}

	foreach ($mode_options as $k => $v)
	{
		$Template->assign_block_vars('mode_options',array(
			'NAME' 		=> $v,
			'SELECTED'	=> $smallads->selected($k, $mode),
			'VALUE' 	=> $k));
	}

	$Template->pparse('smallads');
}

require_once(PATH_TO_ROOT.'/kernel/footer.php');

?>