<?php
/**
 * smallads_interface.class.php
 *
 * @author          alain91
 * @copyright   	(C) 2009-2010 Alain91
 * @email           alain091@gmail.com
 * @license         GPL version 2
 */

defined('PHPBOOST') OR die('Direct script access not allowed');

import('modules/module_interface');

class SmalladsInterface extends ModuleInterface
{
    ## Public Methods ##
    /**
	* @method  Constructeur de l'objet
	*/
    function SmalladsInterface()
    {
        parent::ModuleInterface('smallads');
    }

    /**
	*  @method  Mise à jour du cache
	*/
	function get_cache()
	{
		global $Sql;

		$smallads_code = 'global $CONFIG_SMALLADS;' . "\n";

		//Récupération du tableau linéarisé dans la bdd.
		$CONFIG_SMALLADS = unserialize($Sql->query("SELECT value FROM " . DB_TABLE_CONFIGS . " WHERE name = 'smallads'", __LINE__, __FILE__));
		$CONFIG_SMALLADS = is_array($CONFIG_SMALLADS) ? $CONFIG_SMALLADS : array();

		$smallads_code .= '$CONFIG_SMALLADS = ' . var_export($CONFIG_SMALLADS, true) . ";\n";

		$rand_limit = !empty($CONFIG_SMALLADS['list_size']) ? $CONFIG_SMALLADS['list_size'] : 1;

		$smallads_code .= "\n\n" . 'global $_smallads_mini;' . "\n";

		$result = $Sql->query_while(
			"SELECT q.*, m.login AS mlogin
			FROM ".PREFIX."smallads q
			LEFT JOIN ".PREFIX."member m ON m.user_id = q.id_created
			WHERE (q.approved = 1)
			ORDER BY q.date_approved DESC "
			. $Sql->limit(0, $rand_limit),
			__LINE__, __FILE__);

		$items = array();
		while ($row = $Sql->fetch_assoc($result))
		{
			$items[] = $row;
		}
		$Sql->query_close($result);
		
		$smallads_code .= '$_smallads_mini = ' . var_export($items, true) .";\n";
		
		$smallads_code .= "\n\n" . 'global $_smallads_mini_info;' . "\n";
		
		$last = !empty($items[0]['date_approved']) ? $items[0]['date_approved'] : time();
		$count = $Sql->query("SELECT COUNT(1) FROM ".PREFIX."smallads WHERE (approved = 1) ", __LINE__, __FILE__);
		
		$smallads_code .= '$_smallads_mini_info = ' . var_export(array('count'=>$count, 'date_last'=>$last), true) .";\n";

		return $smallads_code;
	}

    /**
	*  @method  Actions sur changement de jour
	*/
	function on_changeday()
	{
		global $Cache, $Sql, $CONFIG_SMALLADS;

		$Cache->load('smallads');

		$delay = empty($CONFIG_SMALLADS['max_weeks']) ? 0 : abs(intval($CONFIG_SMALLADS['max_weeks']));
		if (!empty($delay))
		{
			$sql = "DELETE FROM ".PREFIX."smallads
				WHERE (approved = 1)
					AND (DATEDIFF(NOW(), FROM_UNIXTIME(date_approved)) > 7 * IFNULL(max_weeks, " . $delay . "))";
			$result = $Sql->query_inject($sql, __LINE__, __FILE__);
		}

		$Cache->generate_module_file('smallads');
	}

	/**
	*  @method  Generation d'un flux RSS
	*
	*/
    function get_feed_data_struct($idcat = 0, $name = '')
    {
        global $Cache, $Sql, $LANG, $CONFIG, $CONFIG_SMALLADS;

        import('content/syndication/feed_data');
        import('util/date');
        import('util/url');

        load_module_lang('smallads');

        $data = new FeedData();

        $data->set_title($LANG['sa_xml_desc'] . ' ' . $CONFIG['server_name']);
        $data->set_date(new Date());
        $data->set_link(new Url('/syndication.php?m=smallads'));
        $data->set_host(HOST);
        $data->set_desc($LANG['sa_xml_desc'] . ' ' . $CONFIG['server_name']);
        $data->set_lang($LANG['xml_lang']);

        // Load the new's config
        $Cache->load('smallads');

        // Last smallads
		$result = $Sql->query_while("SELECT q.*, m.*
			FROM ".PREFIX."smallads q
			LEFT JOIN ".PREFIX."member m ON m.user_id = q.id_created
			WHERE (approved = 1)
			ORDER BY date_created DESC"
			. $Sql->limit(0, $CONFIG_SMALLADS['items_per_page']),
			__LINE__, __FILE__);

        // Generation of the feed's items
        while ($row = $Sql->fetch_assoc($result))
        {
            $item = new FeedItem();

            $item->set_title($row['title']);
            // Rewriting
            $link = new Url('/smallads/smallads.php#smallads_' . $row['id'] );
            $item->set_link($link);
            $item->set_guid($link);
            $item->set_desc(second_parse($row['contents']));
            $item->set_date(new Date(DATE_TIMESTAMP, TIMEZONE_SYSTEM, $row['date_created']));

            $data->add_item($item);
        }
        $Sql->query_close($result);

        return $data;
    }

	/**
	*  @method  Renvoie le formulaire de recherche du module
	*/
    function get_search_form($args=null)
    {
        require_once(PATH_TO_ROOT . '/kernel/begin.php');
		require_once(PATH_TO_ROOT . '/smallads/smallads.class.php');

        load_module_lang('smallads');
        global $CONFIG, $LANG;

        $Tpl = new Template('smallads/smallads_search_form.tpl');

		$smallads = new Smallads();

        if ( empty($args['SmalladsWhere']) || !in_array($args['SmalladsWhere'], explode(',','title,contents,all')) )
            $args['SmalladsWhere'] = 'all';

        $Tpl->assign_vars(Array(
            'L_WHERE' 				=> $LANG['sa_search_where'],
            'IS_TITLE_SELECTED' 	=> $smallads->selected($args['SmalladsWhere'], 'title'),
            'IS_CONTENTS_SELECTED' 	=> $smallads->selected($args['SmalladsWhere'], 'contents'),
            'IS_ALL_SELECTED' 		=> $smallads->selected($args['SmalladsWhere'], 'all'),
            'L_TITLE' 				=> $LANG['sa_db_title'],
            'L_CONTENTS' 			=> $LANG['sa_db_contents']
        ));

        return $Tpl->parse(TEMPLATE_STRING_MODE);
    }

    /**
	*  @method  Renvoie la liste des arguments de la méthode <GetSearchRequest>
	*/
    function get_search_args()
    {
        return Array('SmalladsWhere');
    }

    /**
	*  @method  Renvoie la requête de recherche dans le module
	*/
    function get_search_request($args)
    {
		global $Sql;

        $weight = isset($args['weight']) && is_numeric($args['weight']) ? $args['weight'] : 1;

        if ( empty($args['SmalladsWhere']) || !in_array($args['SmalladsWhere'], explode(',','title,contents,all')) )
            $args['SmalladsWhere'] = 'all';

		$target = PATH_TO_ROOT . '/smallads/smallads.php?id=';

		$smallads 	= new Smallads();
		$mask	 	= 0x08;					// LIST_ACCESS but can't include constants defined in smallads_begin.php (namespace conflicts)

		$access_nok = '';
		if (!$smallads->access_ok($mask))
		{
			$access_nok = ' 0 AND ';
		}

		$req = "SELECT "
				.$args['id_search']." AS `id_search`,
				q.id AS `id_content`,
				q.title AS `title`,
				1 AS `relevance`,
				CONCAT('" . $target . "',q.id) AS `link`
				FROM ".PREFIX."smallads q ";

		switch ($args['SmalladsWhere']) {
			case 'title':
				$req .= " WHERE ".$access_nok.
						" (q.title LIKE '%".$Sql->escape($args['search'])."%')";
				break;

			case 'contents':
				$req .= " WHERE ".$access_nok.
						" (q.contents LIKE '%".$Sql->escape($args['search'])."%')";
				break;

			case 'all':
			default:
				$req .= " WHERE ".$access_nok.
						" ((q.title LIKE '%".$Sql->escape($args['search'])."%')
							OR (q.contents LIKE '%".$Sql->escape($args['search'])."%'))";
		}
        return $req;
    }
}

?>